///////////////////////////////////////////////////////////////////////////////////
// A5 main wdl
////////////////////////////////////////////////////////////////////////////
// Files to over-ride:
// * logodark.bmp - the engine logo, include your game title
// * horizon.pcx - A horizon map displayed over the sky and cloud maps
////////////////////////////////////////////////////////////////////////////
// The PATH keyword gives directories where game files can be found,
// relative to the level directory
path "C:\\art\\Game Dev\\GameStudio\\work\\alexius-shooter\\template";	// Path to WDL templates subdirectory

////////////////////////////////////////////////////////////////////////////
// The INCLUDE keyword can be used to include further WDL files,
// like those in the TEMPLATE subdirectory, with prefabricated actions
include <movement.wdl>;
include <messages.wdl>;
include <menu.wdl>;		// must be inserted before doors and weapons
include <particle.wdl>; // remove when you need no particles
include <doors.wdl>;		// remove when you need no doors
include <actors.wdl>;   // remove when you need no actors
include <weapons.wdl>;  // remove when you need no weapons
include <war.wdl>;      // remove when you need no fighting
//include <venture.wdl>;	// include when doing an adventure
include <lflare.wdl>;   // remove when you need no lens flares
include <collectables.wdl>;
include <enemies.wdl>;  // custom enemy scripts
include <custom_weapons.wdl>; // custom weapon and texts stuff
include <controls.wdl>;


////////////////////////////////////////////////////////////////////////////
// The engine starts in the resolution given by the follwing vars.

var video_mode = 7;	// screen size 800x600
var video_depth = 16;	// 16 bit color D3D mode

function game_resolution()
{
video_mode == 7;	 // screen size 800x600
video_depth == 16; // 16 bit colour D3D mode
wait(1);
}

var ammo1 = 30;

/////////////////////////////////////////////////////////////////
// Strings and filenames
// change this string to your own starting mission message.
string mission_str = "JazzBot ver. 0.07";
string level_str = <shooter.WMB>; // give file names in angular brackets

sound overheat = <overheated.wav>; // The "weapon overheated" sound
string version_number = "JazzBot: ver 0.05\nAll Your Jazz Are Belong To (a dead horse)";
font system_font = <ackfont.pcx>, 6,9;
text ver_number
{
   pos_x = 6;
   pos_y = 574;
   font = system_font;
   string = version_number;
}

/////////////////////////////////////////////////////////////////
// define a splash screen with the required A4/A5 logo
bmap splashmap = <logodark.pcx>; // the default logo in templates
panel splashscreen {
	bmap = splashmap;
	flags = refresh,d3d;
}

bmap lifebarmap = <JX-Lifebar.bmp>;
panel lifebar {
  layer = 2;
  bmap = lifebarmap;
  flags = refresh,d3d,overlay;
}

bmap heatbarmap = <heat_meter.bmp>;  //this is the casing for the health and heat meters
panel heatmeter {
  layer = 2;
  bmap = heatbarmap;
  flags = refresh,d3d,overlay;
}

bmap healthbarmap = <jx-healthbar.bmp>;
var health_pos [2] 0,0;
var heat_pos [2] 0,0;

panel healthbar {
  layer = 1;
  pos_x = 103;
  pos_y = 19;
  flags = refresh,d3d;
  window 0, 0, 132, 23, healthbarmap, health_pos.x, health_pos.y;
}

function health_display() {
 while(1) {
  health_pos.x = 132 - player._health / 100 * 264 /2; //(player._health);
  wait(1);
 }
}

panel heatbar {
  layer = 1;
  pos_x = 100;
  pos_y = 50;
  flags = refresh,d3d;
  window 0, 0, 87, 14, heatbarmap, heat_pos.x, heat_pos.y;
}

function heat_display() {
 while(1) {
  heat_pos.x = ammo1 / 30 * 174 / 2;
  wait(1);
  }
}


////////////////////////////////////////////////////////////////////////////
// The following script controls the sky
sky horizon_sky {
// A backdrop texture's horizontal size must be a power of 2;
// the vertical size does not matter
	type = <mount16.pcx>;
	tilt = -23;
        scale_x = 0.13;	// gives a field of 90 degrees per texture
	flags = scene,overlay,visible;
	layer = 3;
}


var recharge_rate = 0;
string overheat_txt = "OVERHEATING!";

function ammo_recharge()
{
  ammo1 == 30;
  while (1)
  {
    if (ammo1 == 0) 
      {
        snd_play (overheat,100,100);
        msg_blink(overheat_txt,2.5);
        waitt(32);
        ammo1 += 7;
      }
  if (ammo1 < 30)
    {
      ammo1 += 1;
      waitt(10);
    }
  else {ammo1 = 30;}
  wait(1);  
  }   
}
        

action blaster // Standard blaster weapon that slowly recharges ammo
  {
    
    my.__rotate = on;       // weapon rotates when in pickup form
    my.__silent = on;       // picking up the weapon makes no sound
    my.__bob = on;          // weapon bobs when player moves
    my.__repeat = off;      // weapon is not a machine gun
    my._ammotype = 1.30;   // weapon uses ammo type 1. 30 rounds equiped
    my._bulletspeed = 150;  // travels 1200 quants in 1/2 second
    my._weaponnumber = 1;   // Gun is bound to key (1)
    my._firetime = 2;       // 2 ticks between shots
    my._firemode = 14.25; // fires bullets, sparks on impact, 100 damage
    ammo_recharge();
    gun();
    
  }




/////////////////////////////////////////////////////////////////
// The main() function is started at game start
function main()
{
// initiate controls for the custom menu scripts downloaded from Acknex unlimited
init_controls();
// set some common flags and variables
//	warn_level = 2;	// announce bad texture sizes and bad wdl code
	tex_share = on;	// map entities share their textures

// center the splash screen for non-640x480 resolutions, and display it
	splashscreen.pos_x = (screen_size.x - bmap_width(splashmap))/2;
	splashscreen.pos_y = (screen_size.y - bmap_height(splashmap))/2;
	splashscreen.visible = on;
// wait 3 frames (for triple buffering) until it is flipped to the foreground
	wait(3);

// now load the level
	level_load(level_str);
// freeze the game
	freeze_mode = 1;
	
// Play music"sparkster.mid" at 50% volume endlessly.
//media_loop("sparkster.mid",null,150);

// wait the required second, then switch the splashscreen off.
	sleep(1);
  	splashscreen.visible = off;
	bmap_purge(splashmap);	// remove splashscreen from video memory
	
lifebar.pos_x = 3;
lifebar.pos_y = 3;
lifebar.visible = on;
health_display ();
healthbar.visible = on;
heat_display ();
heatbar.visible = on;

// load some global variables, like sound volume
	load_status();

// display the initial message
	msg_show(mission_str,50);

// initialize lens flares when edition supports flares
ifdef CAPS_FLARE;
	lensflare_start();
endif;

// use the new 3rd person camera
	move_view_cap = 1;

// un-freeze the game
	freeze_mode = 0;

// Display the version number
        ver_number.visible = on;


//	client_move();	// for a possible multiplayer game
// call further functions here...

healthpanel.visible = off; // no health digits in the lower left corner

game_resolution();

// Some functions needed to work the main menu downloaded from Acknex Unlimited
targetstart();
startcompass();
ismeniu();
}


/////////////////////////////////////////////////////////////////
// The following definitions are for the pro edition window composer
// to define the start and exit window of the application.
WINDOW WINSTART
{
	TITLE			"3D GameStudio";
	SIZE			480,320;
	MODE			IMAGE;	//STANDARD;
	BG_COLOR		RGB(240,240,240);
	FRAME			FTYP1,0,0,480,320;
//	BUTTON		BUTTON_START,SYS_DEFAULT,"Start",400,288,72,24;
	BUTTON		BUTTON_QUIT,SYS_DEFAULT,"Abort",400,288,72,24;
	TEXT_STDOUT	"Arial",RGB(0,0,0),10,10,460,280;
}

/* no exit window at all..
WINDOW WINEND
{
	TITLE			"Finished";
	SIZE			540,320;
	MODE	 		STANDARD;
	BG_COLOR		RGB(0,0,0);
	TEXT_STDOUT	"",RGB(255,40,40),10,20,520,270;

	SET FONT		"",RGB(0,255,255);
	TEXT			"Any key to exit",10,270;
}*/


/////////////////////////////////////////////////////////////////
//INCLUDE <debug.wdl>;